package de.intevation.flys.artifacts.states;

import org.apache.log4j.Logger;

import org.w3c.dom.Element;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;

import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.artifactdatabase.ProtocolUtils;
import de.intevation.artifactdatabase.data.StateData;

import de.intevation.flys.artifacts.resources.Resources;

/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class WQSelect extends DefaultState {

    /** The logger used in this class.*/
    private static Logger logger = Logger.getLogger(WQSelect.class);


    /** The default step width for Qs.*/
    public static final String DEFAULT_STEP_Q = "50";

    /** The default step width for Qs.*/
    public static final String DEFAULT_STEP_W = "30";

    /**
     * The default constructor that initializes an empty State object.
     */
    public WQSelect() {
    }

    protected Element createData(
        XMLUtils.ElementCreator cr,
        Artifact    artifact,
        StateData   data,
        CallContext context)
    {
        Element select = ProtocolUtils.createArtNode(
            cr, "select", null, null);

        cr.addAttr(select, "name", data.getName(), true);

        Element label = ProtocolUtils.createArtNode(
            cr, "label", null, null);

        Element choices = ProtocolUtils.createArtNode(
            cr, "choices", null, null);

        label.setTextContent(Resources.getMsg(
            context.getMeta(),
            data.getName(),
            data.getName()));

        select.appendChild(label);

        return select;
    }


    protected Element[] createItems(
        XMLUtils.ElementCreator cr,
        Artifact    artifact,
        String      name,
        CallContext context)
    {
        // TODO Insert correct min/max values!

        if (name.equals("wq_from")) {
            Element minW = createItem(cr, new String[] {"minW", "250"});
            Element minQ = createItem(cr, new String[] {"minQ", "5.5"});
            return new Element[] { minW, minQ };
        }
        else if (name.equals("wq_to")) {
            Element maxW = createItem(cr, new String[] {"maxW", "850"});
            Element maxQ = createItem(cr, new String[] {"maxQ", "1530"});
            return new Element[] { maxW, maxQ };
        }
        else {
            Element stepW = createItem(cr, new String[] {"stepW", DEFAULT_STEP_W});
            Element stepQ = createItem(cr, new String[] {"stepQ", DEFAULT_STEP_Q});
            return new Element[] { stepW, stepQ };
        }
    }


    protected Element createItem(XMLUtils.ElementCreator cr, Object obj) {
        Element item  = ProtocolUtils.createArtNode(cr, "item", null, null);
        Element label = ProtocolUtils.createArtNode(cr, "label", null, null);
        Element value = ProtocolUtils.createArtNode(cr, "value", null, null);

        String[] arr = (String[]) obj;

        label.setTextContent(arr[0]);
        value.setTextContent(arr[1]);

        item.appendChild(label);
        item.appendChild(value);

        return item;
    }


    protected String getUIProvider() {
        return "wq_panel";
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
